@@ -10,11 +10,14 @@ import (
 	"time"
 
 	"github.com/Masterminds/semver/v3"
+	"github.com/otiai10/copy"
 )
 
 const (
 	changelogSource = "CHANGELOG.md"
-	changelogTarget = "docs/docs/changelog.md"
+	changelogTarget = "website/docs/changelog.mdx"
+	docsSource      = "website/docs"
+	docsTarget      = "website/versioned_docs/version-latest"
 )
 
 var (
@@ -57,6 +60,10 @@ func release() error {
 		return err
 	}
 
+	if err := docs(); err != nil {
+		return err
+	}
+
 	return nil
 }
 
@@ -135,3 +142,13 @@ func setJSONVersion(fileName string, version *semver.Version) error {
 	// Write the JSON file
 	return os.WriteFile(fileName, []byte(new), 0o644)
 }
+
+func docs() error {
+	if err := os.RemoveAll(docsTarget); err != nil {
+		return err
+	}
+	if err := copy.Copy(docsSource, docsTarget); err != nil {
+		return err
+	}
+	return nil
+}
