@@ -5,7 +5,6 @@ import (
 	"fmt"
 	"log"
 	"os"
-	"path/filepath"
 	"strings"
 
 	"github.com/spf13/pflag"
@@ -94,11 +93,6 @@ func run() error {
 		dir = home
 	}
 
-	if entrypoint != "" {
-		dir = filepath.Dir(entrypoint)
-		entrypoint = filepath.Base(entrypoint)
-	}
-
 	var taskSorter sort.TaskSorter
 	switch flags.TaskSort {
 	case "none":
