@@ -4,22 +4,22 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/go-task/task/v3/taskfile"
+	"github.com/go-task/task/v3/taskfile/ast"
 )
 
 type TaskSorter interface {
-	Sort([]*taskfile.Task)
+	Sort([]*ast.Task)
 }
 
 type Noop struct{}
 
-func (s *Noop) Sort(tasks []*taskfile.Task) {}
+func (s *Noop) Sort(tasks []*ast.Task) {}
 
 type AlphaNumeric struct{}
 
 // Tasks that are not namespaced should be listed before tasks that are.
 // We detect this by searching for a ':' in the task name.
-func (s *AlphaNumeric) Sort(tasks []*taskfile.Task) {
+func (s *AlphaNumeric) Sort(tasks []*ast.Task) {
 	sort.Slice(tasks, func(i, j int) bool {
 		return tasks[i].Task < tasks[j].Task
 	})
@@ -29,7 +29,7 @@ type AlphaNumericWithRootTasksFirst struct{}
 
 // Tasks that are not namespaced should be listed before tasks that are.
 // We detect this by searching for a ':' in the task name.
-func (s *AlphaNumericWithRootTasksFirst) Sort(tasks []*taskfile.Task) {
+func (s *AlphaNumericWithRootTasksFirst) Sort(tasks []*ast.Task) {
 	sort.Slice(tasks, func(i, j int) bool {
 		iContainsColon := strings.Contains(tasks[i].Task, ":")
 		jContainsColon := strings.Contains(tasks[j].Task, ":")
