@@ -9,13 +9,15 @@ type (
 	BaseNode struct {
 		parent   Node
 		optional bool
+		dir      string
 	}
 )
 
-func NewBaseNode(opts ...NodeOption) *BaseNode {
+func NewBaseNode(dir string, opts ...NodeOption) *BaseNode {
 	node := &BaseNode{
 		parent:   nil,
 		optional: false,
+		dir:      dir,
 	}
 
 	// Apply options
@@ -45,3 +47,7 @@ func WithOptional(optional bool) NodeOption {
 func (node *BaseNode) Optional() bool {
 	return node.optional
 }
+
+func (node *BaseNode) Dir() string {
+	return node.dir
+}
